@@ -19,11 +19,14 @@ __all__ = all_mesh + all_assembly + all_element + [  # noqa
     'build_pc_ilu',
     'build_pc_diag',
     'condense',
-    'derivative',
-    'L2_projection',
+    'enforce',
+    'penalize',
     'project',
+    'projection',
     'solve',
     'solver_direct_scipy',
+    'solver_eigen_scipy',
+    'solver_eigen_scipy_sym',
     'solver_iter_pcg',
     'solver_iter_krylov',
 ]
