@@ -1,4 +1,4 @@
-from typing import Union, NamedTuple, Any, List
+from typing import Union, NamedTuple, Any, List, Optional
 
 import numpy as np
 from numpy import ndarray
@@ -159,12 +159,12 @@ class DofsView(NamedTuple):
 class Dofs:
     """An object containing a set of degree-of-freedom indices."""
 
-    nodal_dofs: ndarray = None
-    facet_dofs: ndarray = None
-    edge_dofs: ndarray = None
-    interior_dofs: ndarray = None
+    nodal_dofs: Optional[ndarray] = None
+    facet_dofs: Optional[ndarray] = None
+    edge_dofs: Optional[ndarray] = None
+    interior_dofs: Optional[ndarray] = None
 
-    element_dofs: ndarray = None
+    element_dofs: Optional[ndarray] = None
     N: int = 0
 
     topo: Mesh
@@ -182,7 +182,7 @@ class Dofs:
         offset = element.nodal_dofs * topo.nvertices
 
         # edge dofs
-        if element.dim == 3:
+        if element.dim == 3 and element.edge_dofs > 0:
             self.edge_dofs = np.reshape(
                 np.arange(element.edge_dofs * topo.nedges,
                           dtype=np.int64),
@@ -193,12 +193,15 @@ class Dofs:
             self.edge_dofs = np.empty((0, 0), dtype=np.int64)
 
         # facet dofs
-        self.facet_dofs = np.reshape(
-            np.arange(element.facet_dofs * topo.nfacets,
-                      dtype=np.int64),
-            (element.facet_dofs, topo.nfacets),
-            order='F') + offset
-        offset += element.facet_dofs * topo.nfacets
+        if element.facet_dofs > 0:
+            self.facet_dofs = np.reshape(
+                np.arange(element.facet_dofs * topo.nfacets,
+                          dtype=np.int64),
+                (element.facet_dofs, topo.nfacets),
+                order='F') + offset
+            offset += element.facet_dofs * topo.nfacets
+        else:
+            self.facet_dofs = np.empty((0, 0), dtype=np.int64)
 
         # interior dofs
         self.interior_dofs = np.reshape(
@@ -217,7 +220,7 @@ class Dofs:
             ))
 
         # edge dofs
-        if element.dim == 3:
+        if element.dim == 3 and element.edge_dofs > 0:
             for itr in range(topo.t2e.shape[0]):
                 self.element_dofs = np.vstack((
                     self.element_dofs,
@@ -225,7 +228,7 @@ class Dofs:
                 ))
 
         # facet dofs
-        if element.dim >= 2:
+        if element.dim >= 2 and element.facet_dofs > 0:
             for itr in range(topo.t2f.shape[0]):
                 self.element_dofs = np.vstack((
                     self.element_dofs,
@@ -253,7 +256,7 @@ class Dofs:
 
         """
         if self.element.nodal_dofs > 0 or self.element.edge_dofs > 0:
-            nodal_ix, edge_ix = self.topo.expand_facets(facets)
+            nodal_ix, edge_ix = self.topo._expand_facets(facets)
 
         nodal_ix = (np.empty((0,), dtype=np.int64)
                     if self.element.nodal_dofs == 0
@@ -280,8 +283,8 @@ class Dofs:
     def _by_name(self,
                  dofs: ndarray,
                  off: int = 0,
-                 ix: ndarray = None,
-                 rows: ndarray = None):
+                 ix: Optional[ndarray] = None,
+                 rows: Optional[Union[List[int], ndarray]] = None):
 
         n_dofs = dofs.shape[0]
         n_ents = dofs.shape[1] if ix is None else len(ix)
