@@ -1,14 +1,16 @@
-from typing import Callable, Any, Optional
+import warnings
+from copy import deepcopy
+from functools import partial
+from typing import Any, Callable, Optional
 
 import numpy as np
 from numpy import ndarray
-from scipy.sparse import coo_matrix
 
-from ..basis import Basis
 from ...element import DiscreteField
+from ..basis import Basis
 
 
-class FormDict(dict):
+class FormExtraParams(dict):
     """Passed to forms as 'w'."""
 
     def __getattr__(self, attr):
@@ -17,15 +19,26 @@ class FormDict(dict):
 
 class Form:
 
+    form: Optional[Callable] = None
+
     def __init__(self,
-                 form: Callable = None,
-                 dtype: type = np.float64):
-        self.form = form
+                 form: Optional[Callable] = None,
+                 dtype: type = np.float64,
+                 nthreads: int = 0):
+        self.form = form.form if isinstance(form, Form) else form
         self.dtype = dtype
+        self.nthreads = nthreads
+
+    def partial(self, *args, **kwargs):
+        form = deepcopy(self)
+        form.form = partial(form.form, *args, **kwargs)
+        return form
 
     def __call__(self, *args):
         if self.form is None:  # decorate
-            return type(self)(form=args[0], dtype=self.dtype)
+            return type(self)(form=args[0],
+                              dtype=self.dtype,
+                              nthreads=self.nthreads)
         return self.assemble(self.kernel(*args))
 
     def assemble(self,
@@ -36,30 +49,28 @@ class Form:
 
     @staticmethod
     def dictify(w):
-        """Support some legacy input formats for 'w'."""
+        """Support additional input formats for 'w'."""
         for k in w:
             if isinstance(w[k], DiscreteField):
                 continue
             elif isinstance(w[k], ndarray):
                 w[k] = DiscreteField(w[k])
             elif isinstance(w[k], list):
+                warnings.warn("In future, any additional kwargs to "
+                              "asm() must be of type DiscreteField.",
+                              DeprecationWarning)
                 w[k] = DiscreteField(np.array([z.value for z in w[k]]),
                                      np.array([z.grad for z in w[k]]))
             elif isinstance(w[k], tuple):
+                warnings.warn("In future, any additional kwargs to "
+                              "asm() must be of type DiscreteField. "
+                              "In most cases this deprecation is "
+                              "fixed replacing asm(..., w=w) "
+                              "by asm(..., w=DiscreteField(*w)).",
+                              DeprecationWarning)
                 w[k] = DiscreteField(*w[k])
             else:
                 raise ValueError("The given type '{}' for the list of extra "
                                  "form parameters w cannot be converted to "
                                  "DiscreteField.".format(type(w)))
         return w
-
-    @staticmethod
-    def _assemble_scipy_matrix(data, rows, cols, shape=None):
-        K = coo_matrix((data, (rows, cols)), shape=shape)
-        K.eliminate_zeros()
-        return K.tocsr()
-
-    @staticmethod
-    def _assemble_numpy_vector(data, rows, cols, shape=None):
-        return coo_matrix((data, (rows, cols)),
-                          shape=shape).toarray().T[0]
