@@ -1,17 +1,27 @@
 """Bilinear and linear forms too general to put into a specific model."""
 
 from skfem.assembly import BilinearForm, LinearForm
-from .helpers import div, grad
-
-import numpy as np
+from skfem.helpers import dot, div, curl
 
 
 @BilinearForm
-def divergence(u, v, w):
+def divu(u, v, w):
     return div(u) * v
 
 
+divergence = divu
+
+
+@BilinearForm
+def curluv(u, v, w):
+    return dot(curl(u), v)
+
+
 @LinearForm
 def rot(v, w):
-    return np.einsum('i...,ij...,j...',
-                     w.w, np.array([[0, 1], [-1, 0]]), grad(v))
+    return dot(curl(v), w['w'])
+
+
+@LinearForm
+def vrot(v, w):
+    return dot(v, curl(w['w']))
