@@ -2,15 +2,14 @@
 
 from functools import singledispatch
 
-import matplotlib.pyplot as plt
 import numpy as np
-from matplotlib.axes import Axes
-from mpl_toolkits.mplot3d import Axes3D
 from numpy import ndarray
 
+import matplotlib.pyplot as plt
+from matplotlib.axes import Axes
+
 from ..assembly import InteriorBasis
-from ..mesh import Mesh2D, MeshLine, MeshTri,\
-    MeshTet, MeshQuad
+from ..mesh import Mesh2D, MeshLine, MeshQuad, MeshTet, MeshTri
 
 
 @singledispatch
@@ -21,8 +20,13 @@ def draw(m, **kwargs) -> Axes:
 
 @draw.register(InteriorBasis)
 def draw_basis(ib: InteriorBasis, **kwargs) -> Axes:
-    Nrefs = kwargs["Nrefs"] if "Nrefs" in kwargs else 1
-    m, _ = ib.refinterp(ib.mesh.p[0], Nrefs=Nrefs)
+    if "nrefs" in kwargs:
+        nrefs = kwargs["nrefs"]
+    elif "Nrefs" in kwargs:
+        nrefs = kwargs["Nrefs"]
+    else:
+        nrefs = 1
+    m, _ = ib.refinterp(ib.mesh.p[0], nrefs=nrefs)
     return draw(m, boundaries_only=True, **kwargs)
 
 
@@ -30,8 +34,7 @@ def draw_basis(ib: InteriorBasis, **kwargs) -> Axes:
 def draw_meshtet(m: MeshTet, **kwargs) -> Axes:
     """Visualize a tetrahedral mesh by drawing the boundary facets."""
     bnd_facets = m.boundary_facets()
-    fig = plt.figure()
-    ax = Axes3D(fig)
+    ax = plt.figure().add_subplot(1, 1, 1, projection='3d')
     indexing = m.facets[:, bnd_facets].T
     ax.plot_trisurf(m.p[0], m.p[1], m.p[2],
                     triangles=indexing, cmap=plt.cm.viridis, edgecolor='k')
@@ -50,14 +53,16 @@ def draw_mesh2d(m: Mesh2D, **kwargs) -> Axes:
     ax (optional)
         A preinitialised Matplotlib axes for plotting.
     node_numbering (optional)
-        If true, draw node numbering.
+        If ``True``, draw node numbering.
     facet_numbering (optional)
-        If true, draw facet numbering.
+        If ``True``, draw facet numbering.
     element_numbering (optional)
-        If true, draw element numbering.
+        If ``True``, draw element numbering.
     aspect (optional)
-        Ratio of vertical to horizontal length-scales; ignored if ax
+        Ratio of vertical to horizontal length-scales; ignored if ``ax`` is
         specified
+    boundaries_only (optional)
+        If ``True``, draw only boundary edges.
 
     Returns
     -------
@@ -129,11 +134,12 @@ def plot_meshline(m: MeshLine, z: ndarray, **kwargs):
         # create new figure
         fig = plt.figure()
         ax = fig.add_subplot(111)
-        xs = []
-        ys = []
     else:
         ax = kwargs["ax"]
 
+    xs = []
+    ys = []
+
     color = kwargs["color"] if "color" in kwargs else 'ko-'
     for y1, y2, s, t in zip(z[m.t[0]],
                             z[m.t[1]],
@@ -145,7 +151,8 @@ def plot_meshline(m: MeshLine, z: ndarray, **kwargs):
         ys.append(y1)
         ys.append(y2)
         ys.append(None)
-        ax.plot(xs, ys, color)
+
+    ax.plot(xs, ys, color)
 
     return ax
 
@@ -214,17 +221,22 @@ def plot_meshquad(m: MeshQuad, z, **kwargs):
 
     """
     if len(z) == m.t.shape[-1]:
-        m, z = m._splitquads(z)
+        m, z = m.to_meshtri(z)
     else:
-        m = m._splitquads()
+        m = m.to_meshtri()
     return plot(m, z, **kwargs)
 
 
 @plot.register(InteriorBasis)
 def plot_basis(basis: InteriorBasis, z: ndarray, **kwargs) -> Axes:
     """Plot on a refined mesh via :meth:`InteriorBasis.refinterp`."""
-    Nrefs = kwargs["Nrefs"] if "Nrefs" in kwargs else 1
-    return plot(*basis.refinterp(z, Nrefs=Nrefs), **kwargs)
+    if "nrefs" in kwargs:
+        nrefs = kwargs["nrefs"]
+    elif "Nrefs" in kwargs:
+        nrefs = kwargs["Nrefs"]
+    else:
+        nrefs = 1
+    return plot(*basis.refinterp(z, nrefs=nrefs), **kwargs)
 
 
 @singledispatch
@@ -250,11 +262,7 @@ def plot3_meshtri(m: MeshTri, z: ndarray, **kwargs) -> Axes:
         The Matplotlib axes onto which the mesh was plotted.
 
     """
-    if "ax" not in kwargs:
-        fig = plt.figure()
-        ax = Axes3D(fig)
-    else:
-        ax = kwargs["ax"]
+    ax = kwargs.get("ax", plt.figure().add_subplot(1, 1, 1, projection='3d'))
 
     ax.plot_trisurf(m.p[0], m.p[1], z,
                     triangles=m.t.T,
@@ -267,8 +275,13 @@ def plot3_meshtri(m: MeshTri, z: ndarray, **kwargs) -> Axes:
 @plot3.register(InteriorBasis)
 def plot3_basis(basis: InteriorBasis, z: ndarray, **kwargs) -> Axes:
     """Plot on a refined mesh via :meth:`InteriorBasis.refinterp`."""
-    Nrefs = kwargs["Nrefs"] if "Nrefs" in kwargs else 1
-    return plot3(*basis.refinterp(z, Nrefs=Nrefs), **kwargs)
+    if "nrefs" in kwargs:
+        nrefs = kwargs["nrefs"]
+    elif "Nrefs" in kwargs:
+        nrefs = kwargs["Nrefs"]
+    else:
+        nrefs = 1
+    return plot3(*basis.refinterp(z, nrefs=nrefs), **kwargs)
 
 
 def savefig(*args, **kwargs):
